# Branding Settings
### On this page
  * [Workspace Designs](https://help.sap.com/docs/leanix/ea/branding-settings#workspace-designs)
  * [Applying a Custom Design to a Workspace](https://help.sap.com/docs/leanix/ea/branding-settings#applying-a-custom-design-to-a-workspace)


Personalize your workspace's appearance to reflect your brand identity or choose from one of the predefined workspace designs.
In the Branding section of the administration area, you can apply a custom workspace design that aligns with your brand identity or select a predefined design. Additionally, in the Logo in Exports section on the branding settings page, you can upload a custom logo to be used in exported reports and diagrams.
